@@ -15,9 +15,7 @@
  */
 
 #define C_CFISH_STRING
-#define C_CFISH_STACKSTRING
 #define C_CFISH_STRINGITERATOR
-#define C_CFISH_STACKSTRINGITERATOR
 #define CFISH_USE_SHORT_NAMES
 
 #include <string.h>
@@ -28,15 +26,14 @@
 #include "Clownfish/Class.h"
 #include "Clownfish/String.h"
 
+#include "Clownfish/ByteBuf.h"
 #include "Clownfish/CharBuf.h"
 #include "Clownfish/Err.h"
 #include "Clownfish/Util/Memory.h"
 #include "Clownfish/Util/StringHelper.h"
 
-#define STR_STACKTOP(string) \
-    Str_StackTop(string, alloca(sizeof(StackStringIterator)))
-#define STR_STACKTAIL(string) \
-    Str_StackTail(string, alloca(sizeof(StackStringIterator)))
+#define STACK_ITER(string, byte_offset) \
+    S_new_stack_iter(alloca(sizeof(StringIterator)), string, byte_offset)
 
 // Helper function for throwing invalid UTF-8 error. Since THROW uses
 // a String internally, calling THROW with invalid UTF-8 would create an
@@ -48,6 +45,12 @@ static void
 S_die_invalid_utf8(const char *text, size_t size, const char *file, int line,
                    const char *func);
 
+static const char*
+S_memmem(String *self, const char *substring, size_t size);
+
+static StringIterator*
+S_new_stack_iter(void *allocation, String *string, size_t byte_offset);
+
 String*
 Str_new_from_utf8(const char *utf8, size_t size) {
     if (!StrHelp_utf8_valid(utf8, size)) {
@@ -118,6 +121,12 @@ Str_new_wrap_trusted_utf8(const char *utf8, size_t size) {
     return Str_init_wrap_trusted_utf8(self, utf8, size);
 }
 
+String*
+Str_init_stack_string(void *allocation, const char *utf8, size_t size) {
+    String *self = (String*)Class_Init_Obj(STRING, allocation);
+    return Str_init_wrap_trusted_utf8(self, utf8, size);
+}
+
 String*
 Str_init_wrap_trusted_utf8(String *self, const char *ptr, size_t size) {
     self->ptr    = ptr;
@@ -169,18 +178,9 @@ S_new_substring(String *string, size_t byte_offset, size_t size) {
     return self;
 }
 
-Obj*
-Str_Inc_RefCount_IMP(String *self) {
-    if (self->origin == NULL) {
-        // Copy wrapped strings when the refcount is increased.
-        String *copy = (String*)Class_Make_Obj(STRING);
-        return (Obj*)Str_init_from_trusted_utf8(copy, self->ptr, self->size);
-    }
-    else {
-        Str_Inc_RefCount_t super_incref
-            = SUPER_METHOD_PTR(STRING, CFISH_Str_Inc_RefCount);
-        return super_incref(self);
-    }
+bool
+Str_Is_Copy_On_IncRef_IMP(String *self) {
+    return self->origin == NULL;
 }
 
 void
@@ -194,19 +194,18 @@ Str_Destroy_IMP(String *self) {
     SUPER_DESTROY(self, STRING);
 }
 
-int32_t
+size_t
 Str_Hash_Sum_IMP(String *self) {
-    uint32_t hashvalue = 5381;
-    StackStringIterator *iter = STR_STACKTOP(self);
+    size_t hashvalue = 5381;
+    StringIterator *iter = STACK_ITER(self, 0);
 
-    const SStrIter_Next_t next
-        = METHOD_PTR(STACKSTRINGITERATOR, CFISH_SStrIter_Next);
+    const StrIter_Next_t next = METHOD_PTR(STRINGITERATOR, CFISH_StrIter_Next);
     int32_t code_point;
-    while (STRITER_DONE != (code_point = next(iter))) {
+    while (STR_OOB != (code_point = next(iter))) {
         hashvalue = ((hashvalue << 5) + hashvalue) ^ code_point;
     }
 
-    return (int32_t) hashvalue;
+    return hashvalue;
 }
 
 static void
@@ -224,22 +223,6 @@ Str_To_String_IMP(String *self) {
     return (String*)INCREF(self);
 }
 
-String*
-Str_Swap_Chars_IMP(String *self, int32_t match, int32_t replacement) {
-    CharBuf *charbuf = CB_new(self->size);
-    StackStringIterator *iter = STR_STACKTOP(self);
-    int32_t code_point;
-
-    while (STRITER_DONE != (code_point = SStrIter_Next(iter))) {
-        if (code_point == match) { code_point = replacement; }
-        CB_Cat_Char(charbuf, code_point);
-    }
-
-    String *retval = CB_Yield_String(charbuf);
-    DECREF(charbuf);
-    return retval;
-}
-
 int64_t
 Str_To_I64_IMP(String *self) {
     return Str_BaseX_To_I64(self, 10);
@@ -247,31 +230,31 @@ Str_To_I64_IMP(String *self) {
 
 int64_t
 Str_BaseX_To_I64_IMP(String *self, uint32_t base) {
-    StackStringIterator *iter = STR_STACKTOP(self);
+    StringIterator *iter = STACK_ITER(self, 0);
     int64_t retval = 0;
     bool is_negative = false;
-    int32_t code_point = SStrIter_Next(iter);
+    int32_t code_point = StrIter_Next(iter);
 
     // Advance past minus sign.
     if (code_point == '-') {
-        code_point = SStrIter_Next(iter);
+        code_point = StrIter_Next(iter);
         is_negative = true;
     }
 
     // Accumulate.
-    while (code_point != STRITER_DONE) {
+    while (code_point != STR_OOB) {
         if (isalnum(code_point)) {
             int32_t addend = isdigit(code_point)
                              ? code_point - '0'
                              : tolower(code_point) - 'a' + 10;
-            if (addend > (int32_t)base) { break; }
+            if (addend >= (int32_t)base) { break; }
             retval *= base;
             retval += addend;
         }
         else {
             break;
         }
-        code_point = SStrIter_Next(iter);
+        code_point = StrIter_Next(iter);
     }
 
     // Apply minus sign.
@@ -308,6 +291,11 @@ Str_To_Utf8_IMP(String *self) {
     return buf;
 }
 
+ByteBuf*
+Str_To_ByteBuf_IMP(String *self) {
+    return BB_new_bytes(self->ptr, self->size);
+}
+
 String*
 Str_Clone_IMP(String *self) {
     return (String*)INCREF(self);
@@ -358,14 +346,30 @@ bool
 Str_Equals_IMP(String *self, Obj *other) {
     String *const twin = (String*)other;
     if (twin == self)              { return true; }
-    if (!Obj_Is_A(other, STRING)) { return false; }
+    if (!Obj_is_a(other, STRING)) { return false; }
     return Str_Equals_Utf8_IMP(self, twin->ptr, twin->size);
 }
 
 int32_t
 Str_Compare_To_IMP(String *self, Obj *other) {
-    CERTIFY(other, STRING);
-    return Str_compare(&self, &other);
+    String  *twin = (String*)CERTIFY(other, STRING);
+    size_t   min_size;
+    int32_t  tie;
+
+    if (self->size <= twin->size) {
+        min_size = self->size;
+        tie      = self->size < twin->size ? -1 : 0;
+    }
+    else {
+        min_size = twin->size;
+        tie      = 1;
+    }
+
+    int comparison = memcmp(self->ptr, twin->ptr, min_size);
+    if (comparison < 0) { return -1; }
+    if (comparison > 0) { return 1; }
+
+    return tie;
 }
 
 bool
@@ -377,15 +381,15 @@ Str_Equals_Utf8_IMP(String *self, const char *ptr, size_t size) {
 }
 
 bool
-Str_Ends_With_IMP(String *self, String *postfix) {
-    return Str_Ends_With_Utf8_IMP(self, postfix->ptr, postfix->size);
+Str_Ends_With_IMP(String *self, String *suffix) {
+    return Str_Ends_With_Utf8_IMP(self, suffix->ptr, suffix->size);
 }
 
 bool
-Str_Ends_With_Utf8_IMP(String *self, const char *postfix, size_t postfix_len) {
-    if (postfix_len <= self->size) {
-        const char *start = self->ptr + self->size - postfix_len;
-        if (memcmp(start, postfix, postfix_len) == 0) {
+Str_Ends_With_Utf8_IMP(String *self, const char *suffix, size_t suffix_len) {
+    if (suffix_len <= self->size) {
+        const char *start = self->ptr + self->size - suffix_len;
+        if (memcmp(start, suffix, suffix_len) == 0) {
             return true;
         }
     }
@@ -393,119 +397,107 @@ Str_Ends_With_Utf8_IMP(String *self, const char *postfix, size_t postfix_len) {
     return false;
 }
 
-int64_t
+bool
+Str_Contains_IMP(String *self, String *substring) {
+    return !!S_memmem(self, substring->ptr, substring->size);
+}
+
+bool
+Str_Contains_Utf8_IMP(String *self, const char *substring, size_t size) {
+    return !!S_memmem(self, substring, size);
+}
+
+StringIterator*
 Str_Find_IMP(String *self, String *substring) {
     return Str_Find_Utf8(self, substring->ptr, substring->size);
 }
 
-int64_t
-Str_Find_Utf8_IMP(String *self, const char *ptr, size_t size) {
-    StackStringIterator *iter = STR_STACKTOP(self);
-    int64_t location = 0;
+StringIterator*
+Str_Find_Utf8_IMP(String *self, const char *substring, size_t size) {
+    const char *ptr = S_memmem(self, substring, size);
+    return ptr ? StrIter_new(self, ptr - self->ptr) : NULL;
+}
 
-    while (iter->byte_offset + size <= self->size) {
-        if (memcmp(self->ptr + iter->byte_offset, ptr, size) == 0) {
-            return location;
-        }
-        SStrIter_Advance(iter, 1);
-        location++;
+static const char*
+S_memmem(String *self, const char *substring, size_t size) {
+    if (size == 0)         { return self->ptr; }
+    if (size > self->size) { return NULL;      }
+
+    const char *ptr = self->ptr;
+    const char *end = ptr + self->size - size + 1;
+    char first_char = substring[0];
+
+    // Naive string search.
+    while (NULL != (ptr = (const char*)memchr(ptr, first_char, end - ptr))) {
+        if (memcmp(ptr, substring, size) == 0) { break; }
+        ptr++;
     }
 
-    return -1;
+    return ptr;
 }
 
 String*
 Str_Trim_IMP(String *self) {
-    StackStringIterator *top = STR_STACKTOP(self);
-    SStrIter_Skip_Next_Whitespace(top);
+    StringIterator *top = STACK_ITER(self, 0);
+    StrIter_Skip_Whitespace(top);
 
-    StackStringIterator *tail = NULL;
+    StringIterator *tail = NULL;
     if (top->byte_offset < self->size) {
-        tail = STR_STACKTAIL(self);
-        SStrIter_Skip_Prev_Whitespace(tail);
+        tail = STACK_ITER(self, self->size);
+        StrIter_Skip_Whitespace_Back(tail);
     }
 
-    return StrIter_substring((StringIterator*)top, (StringIterator*)tail);
+    return StrIter_crop((StringIterator*)top, (StringIterator*)tail);
 }
 
 String*
 Str_Trim_Top_IMP(String *self) {
-    StackStringIterator *top = STR_STACKTOP(self);
-    SStrIter_Skip_Next_Whitespace(top);
-    return StrIter_substring((StringIterator*)top, NULL);
+    StringIterator *top = STACK_ITER(self, 0);
+    StrIter_Skip_Whitespace(top);
+    return StrIter_crop((StringIterator*)top, NULL);
 }
 
 String*
 Str_Trim_Tail_IMP(String *self) {
-    StackStringIterator *tail = STR_STACKTAIL(self);
-    SStrIter_Skip_Prev_Whitespace(tail);
-    return StrIter_substring(NULL, (StringIterator*)tail);
+    StringIterator *tail = STACK_ITER(self, self->size);
+    StrIter_Skip_Whitespace_Back(tail);
+    return StrIter_crop(NULL, (StringIterator*)tail);
 }
 
 size_t
 Str_Length_IMP(String *self) {
-    StackStringIterator *iter = STR_STACKTOP(self);
-    return SStrIter_Advance(iter, SIZE_MAX);
+    StringIterator *iter = STACK_ITER(self, 0);
+    return StrIter_Advance(iter, SIZE_MAX);
 }
 
 int32_t
 Str_Code_Point_At_IMP(String *self, size_t tick) {
-    StackStringIterator *iter = STR_STACKTOP(self);
-    SStrIter_Advance(iter, tick);
-    int32_t code_point = SStrIter_Next(iter);
-    return code_point == STRITER_DONE ? 0 : code_point;
+    StringIterator *iter = STACK_ITER(self, 0);
+    StrIter_Advance(iter, tick);
+    return StrIter_Next(iter);
 }
 
 int32_t
 Str_Code_Point_From_IMP(String *self, size_t tick) {
-    if (tick == 0) { return 0; }
-    StackStringIterator *iter = STR_STACKTAIL(self);
-    SStrIter_Recede(iter, tick - 1);
-    int32_t code_point = SStrIter_Prev(iter);
-    return code_point == STRITER_DONE ? 0 : code_point;
+    if (tick == 0) { return STR_OOB; }
+    StringIterator *iter = STACK_ITER(self, self->size);
+    StrIter_Recede(iter, tick - 1);
+    return StrIter_Prev(iter);
 }
 
 String*
 Str_SubString_IMP(String *self, size_t offset, size_t len) {
-    StackStringIterator *iter = STR_STACKTOP(self);
+    StringIterator *iter = STACK_ITER(self, 0);
 
-    SStrIter_Advance(iter, offset);
+    StrIter_Advance(iter, offset);
     size_t start_offset = iter->byte_offset;
 
-    SStrIter_Advance(iter, len);
+    StrIter_Advance(iter, len);
     size_t size = iter->byte_offset - start_offset;
 
     return S_new_substring(self, start_offset, size);
 }
 
-int
-Str_compare(const void *va, const void *vb) {
-    String *a = *(String**)va;
-    String *b = *(String**)vb;
-    size_t min_size;
-    int    tie;
-
-    if (a->size <= b->size) {
-        min_size = a->size;
-        tie      = a->size < b->size ? -1 : 0;
-    }
-    else {
-        min_size = b->size;
-        tie      = 1;
-    }
-
-    int comparison = memcmp(a->ptr, b->ptr, min_size);
-    if (comparison < 0) { return -1; }
-    if (comparison > 0) { return 1; }
-
-    return tie;
-}
-
-bool
-Str_less_than(const void *va, const void *vb) {
-    return Str_compare(va, vb) < 0 ? true : false;
-}
-
 size_t
 Str_Get_Size_IMP(String *self) {
     return self->size;
@@ -526,62 +518,6 @@ Str_Tail_IMP(String *self) {
     return StrIter_new(self, self->size);
 }
 
-StackStringIterator*
-Str_StackTop_IMP(String *self, void *allocation) {
-    return SStrIter_new(allocation, self, 0);
-}
-
-StackStringIterator*
-Str_StackTail_IMP(String *self, void *allocation) {
-    return SStrIter_new(allocation, self, self->size);
-}
-
-/*****************************************************************/
-
-StackString*
-SStr_new_from_str(void *allocation, size_t alloc_size, String *string) {
-    size_t  size = string->size;
-    char   *ptr  = ((char*)allocation) + sizeof(StackString);
-
-    if (alloc_size < sizeof(StackString) + size + 1) {
-        THROW(ERR, "alloc_size of StackString too small");
-    }
-
-    memcpy(ptr, string->ptr, size);
-    ptr[size] = '\0';
-
-    StackString *self = (StackString*)Class_Init_Obj(STACKSTRING, allocation);
-    self->ptr    = ptr;
-    self->size   = size;
-    self->origin = NULL;
-    return self;
-}
-
-StackString*
-SStr_wrap_str(void *allocation, const char *ptr, size_t size) {
-    StackString *self
-        = (StackString*)Class_Init_Obj(STACKSTRING, allocation);
-    self->size   = size;
-    self->ptr    = ptr;
-    self->origin = NULL;
-    return self;
-}
-
-StackString*
-SStr_wrap(void *allocation, String *source) {
-    return SStr_wrap_str(allocation, source->ptr, source->size);
-}
-
-size_t
-SStr_size() {
-    return sizeof(StackString);
-}
-
-void
-SStr_Destroy_IMP(StackString *self) {
-    THROW(ERR, "Can't destroy a StackString ('%o')", self);
-}
-
 /*****************************************************************/
 
 StringIterator*
@@ -592,15 +528,27 @@ StrIter_new(String *string, size_t byte_offset) {
     return self;
 }
 
+static StringIterator*
+S_new_stack_iter(void *allocation, String *string, size_t byte_offset) {
+    StringIterator *self
+        = (StringIterator*)Class_Init_Obj(STRINGITERATOR, allocation);
+    // Assume that the string will be available for the lifetime of the
+    // iterator and don't increase its refcount.
+    self->string      = string;
+    self->byte_offset = byte_offset;
+    return self;
+}
+
 String*
-StrIter_substring(StringIterator *top, StringIterator *tail) {
+StrIter_crop(StringIterator *top, StringIterator *tail) {
     String *string;
     size_t  top_offset;
     size_t  tail_offset;
 
     if (tail == NULL) {
         if (top == NULL) {
-            THROW(ERR, "StrIter_substring: Both top and tail are NULL");
+            THROW(ERR, "StrIter_crop: Both top and tail are NULL");
+            UNREACHABLE_RETURN(String*);
         }
         string      = top->string;
         tail_offset = string->size;
@@ -608,13 +556,11 @@ StrIter_substring(StringIterator *top, StringIterator *tail) {
     else {
         string = tail->string;
         if (top != NULL && string != top->string) {
-            THROW(ERR, "StrIter_substring: strings don't match");
+            THROW(ERR, "StrIter_crop: strings don't match");
+            UNREACHABLE_RETURN(String*);
         }
 
         tail_offset = tail->byte_offset;
-        if (tail_offset > string->size) {
-            THROW(ERR, "Invalid StringIterator offset");
-        }
     }
 
     if (top == NULL) {
@@ -623,7 +569,8 @@ StrIter_substring(StringIterator *top, StringIterator *tail) {
     else {
         top_offset = top->byte_offset;
         if (top_offset > tail_offset) {
-            THROW(ERR, "StrIter_substring: top is behind tail");
+            THROW(ERR, "StrIter_crop: top is behind tail");
+            UNREACHABLE_RETURN(String*);
         }
     }
 
@@ -648,7 +595,7 @@ bool
 StrIter_Equals_IMP(StringIterator *self, Obj *other) {
     StringIterator *const twin = (StringIterator*)other;
     if (twin == self)                     { return true; }
-    if (!Obj_Is_A(other, STRINGITERATOR)) { return false; }
+    if (!Obj_is_a(other, STRINGITERATOR)) { return false; }
     return self->string == twin->string
            && self->byte_offset == twin->byte_offset;
 }
@@ -658,6 +605,7 @@ StrIter_Compare_To_IMP(StringIterator *self, Obj *other) {
     StringIterator *twin = (StringIterator*)CERTIFY(other, STRINGITERATOR);
     if (self->string != twin->string) {
         THROW(ERR, "Can't compare iterators of different strings");
+        UNREACHABLE_RETURN(int32_t);
     }
     if (self->byte_offset < twin->byte_offset) { return -1; }
     if (self->byte_offset > twin->byte_offset) { return 1; }
@@ -680,7 +628,7 @@ StrIter_Next_IMP(StringIterator *self) {
     size_t  byte_offset = self->byte_offset;
     size_t  size        = string->size;
 
-    if (byte_offset >= size) { return STRITER_DONE; }
+    if (byte_offset >= size) { return STR_OOB; }
 
     const uint8_t *const ptr = (const uint8_t*)string->ptr;
     int32_t retval = ptr[byte_offset++];
@@ -715,6 +663,7 @@ StrIter_Next_IMP(StringIterator *self) {
         do {
             if (byte_offset >= size) {
                 THROW(ERR, "StrIter_Next: Invalid UTF-8");
+                UNREACHABLE_RETURN(int32_t);
             }
 
             retval = (retval << 6) | (ptr[byte_offset++] & 0x3F);
@@ -732,7 +681,7 @@ int32_t
 StrIter_Prev_IMP(StringIterator *self) {
     size_t byte_offset = self->byte_offset;
 
-    if (byte_offset == 0) { return STRITER_DONE; }
+    if (byte_offset == 0) { return STR_OOB; }
 
     const uint8_t *const ptr = (const uint8_t*)self->string->ptr;
     int32_t retval = ptr[--byte_offset];
@@ -742,6 +691,7 @@ StrIter_Prev_IMP(StringIterator *self) {
 
         if (byte_offset == 0) {
             THROW(ERR, "StrIter_Prev: Invalid UTF-8");
+            UNREACHABLE_RETURN(int32_t);
         }
 
         retval &= 0x3F;
@@ -752,6 +702,7 @@ StrIter_Prev_IMP(StringIterator *self) {
         while ((byte & 0xC0) == 0x80) {
             if (byte_offset == 0) {
                 THROW(ERR, "StrIter_Prev: Invalid UTF-8");
+                UNREACHABLE_RETURN(int32_t);
             }
 
             retval |= (byte & 0x3F) << shift;
@@ -785,6 +736,7 @@ StrIter_Advance_IMP(StringIterator *self, size_t num) {
 
     if (byte_offset > size) {
         THROW(ERR, "StrIter_Advance: Invalid UTF-8");
+        UNREACHABLE_RETURN(size_t);
     }
 
     self->byte_offset = byte_offset;
@@ -806,6 +758,7 @@ StrIter_Recede_IMP(StringIterator *self, size_t num) {
         do {
             if (byte_offset == 0) {
                 THROW(ERR, "StrIter_Recede: Invalid UTF-8");
+                UNREACHABLE_RETURN(size_t);
             }
 
             byte = ptr[--byte_offset];
@@ -818,12 +771,12 @@ StrIter_Recede_IMP(StringIterator *self, size_t num) {
 }
 
 size_t
-StrIter_Skip_Next_Whitespace_IMP(StringIterator *self) {
+StrIter_Skip_Whitespace_IMP(StringIterator *self) {
     size_t  num_skipped = 0;
     size_t  byte_offset = self->byte_offset;
     int32_t code_point;
 
-    while (STRITER_DONE != (code_point = StrIter_Next(self))) {
+    while (STR_OOB != (code_point = StrIter_Next(self))) {
         if (!StrHelp_is_whitespace(code_point)) { break; }
         byte_offset = self->byte_offset;
         ++num_skipped;
@@ -834,12 +787,12 @@ StrIter_Skip_Next_Whitespace_IMP(StringIterator *self) {
 }
 
 size_t
-StrIter_Skip_Prev_Whitespace_IMP(StringIterator *self) {
+StrIter_Skip_Whitespace_Back_IMP(StringIterator *self) {
     size_t  num_skipped = 0;
     size_t  byte_offset = self->byte_offset;
     int32_t code_point;
 
-    while (STRITER_DONE != (code_point = StrIter_Prev(self))) {
+    while (STR_OOB != (code_point = StrIter_Prev(self))) {
         if (!StrHelp_is_whitespace(code_point)) { break; }
         byte_offset = self->byte_offset;
         ++num_skipped;
@@ -860,33 +813,25 @@ StrIter_Starts_With_Utf8_IMP(StringIterator *self, const char *prefix,
     String *string      = self->string;
     size_t  byte_offset = self->byte_offset;
 
-    if (byte_offset > string->size) {
-        THROW(ERR, "Invalid StringIterator offset");
-    }
-
     if (string->size - byte_offset < size) { return false; }
 
     return memcmp(string->ptr + byte_offset, prefix, size) == 0;
 }
 
 bool
-StrIter_Ends_With_IMP(StringIterator *self, String *postfix) {
-    return StrIter_Ends_With_Utf8_IMP(self, postfix->ptr, postfix->size);
+StrIter_Ends_With_IMP(StringIterator *self, String *suffix) {
+    return StrIter_Ends_With_Utf8_IMP(self, suffix->ptr, suffix->size);
 }
 
 bool
-StrIter_Ends_With_Utf8_IMP(StringIterator *self, const char *postfix,
+StrIter_Ends_With_Utf8_IMP(StringIterator *self, const char *suffix,
                            size_t size) {
     String *string      = self->string;
     size_t  byte_offset = self->byte_offset;
 
-    if (byte_offset > string->size) {
-        THROW(ERR, "Invalid StringIterator offset");
-    }
-
     if (byte_offset < size) { return false; }
 
-    return memcmp(string->ptr + byte_offset - size, postfix, size) == 0;
+    return memcmp(string->ptr + byte_offset - size, suffix, size) == 0;
 }
 
 void
@@ -895,24 +840,4 @@ StrIter_Destroy_IMP(StringIterator *self) {
     SUPER_DESTROY(self, STRINGITERATOR);
 }
 
-/*****************************************************************/
-
-StackStringIterator*
-SStrIter_new(void *allocation, String *string, size_t byte_offset) {
-    StackStringIterator *self
-        = (StackStringIterator*)Class_Init_Obj(STACKSTRINGITERATOR,
-                                                allocation);
-    // Assume that the string will be available for the lifetime of the
-    // iterator and don't increase its refcount.
-    self->string      = string;
-    self->byte_offset = byte_offset;
-    return self;
-}
-
-void
-SStrIter_Destroy_IMP(StackStringIterator *self) {
-    UNUSED_VAR(self);
-    THROW(ERR, "Can't destroy a StackStringIterator");
-}
-
 
