@@ -20,7 +20,7 @@ package Clownfish;
 
 use 5.008003;
 
-our $VERSION = '0.004099_001';
+our $VERSION = '0.004099_002';
 $VERSION = eval $VERSION;
 our $MAJOR_VERSION = 0.004000;
 
@@ -38,14 +38,14 @@ BEGIN {
     require DynaLoader;
     our @ISA = qw( DynaLoader );
     # This loads a large number of disparate subs.
-    bootstrap Clownfish '0.4.99_1';
+    bootstrap Clownfish '0.4.99_2';
 }
 
 sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Util::StringHelper;
-    our $VERSION = '0.004099_001';
+    our $VERSION = '0.004099_002';
     $VERSION = eval $VERSION;
     BEGIN {
         push our @ISA, 'Exporter';
@@ -63,7 +63,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Obj;
-    our $VERSION = '0.004099_001';
+    our $VERSION = '0.004099_002';
     $VERSION = eval $VERSION;
     use Carp qw( confess );
     # Clownfish objects are not thread-safe.
@@ -80,7 +80,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Class;
-    our $VERSION = '0.004099_001';
+    our $VERSION = '0.004099_002';
     $VERSION = eval $VERSION;
 
     sub _find_parent_class {
@@ -123,7 +123,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Method;
-    our $VERSION = '0.004099_001';
+    our $VERSION = '0.004099_002';
     $VERSION = eval $VERSION;
     no warnings 'redefine';
     sub CLONE_SKIP { 0; }
@@ -132,7 +132,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Err;
-    our $VERSION = '0.004099_001';
+    our $VERSION = '0.004099_002';
     $VERSION = eval $VERSION;
     sub do_to_string { shift->to_string }
     use Scalar::Util qw( blessed );
@@ -171,7 +171,7 @@ sub error {$Clownfish::Err::error}
 
 {
     package Clownfish::Boolean;
-    our $VERSION = '0.004099_001';
+    our $VERSION = '0.004099_002';
     $VERSION = eval $VERSION;
     use Exporter 'import';
     our @EXPORT_OK = qw( $true_singleton $false_singleton );
@@ -181,31 +181,3 @@ sub error {$Clownfish::Err::error}
 
 1;
 
-__END__
-
-=head1 NAME
-
-Clownfish - Apache Clownfish symbiotic object system.
-
-=head1 VERSION
-
-0.4.99_1
-
-=head1 DESCRIPTION
-
-The Apache Clownfish "symbiotic" object system for C is designed to pair with
-a "host" dynamic language environment, facilitating the development of high
-performance host language extensions.  Clownfish classes are declared in
-header files with a C<.cfh> extension.  The Clownfish headers are used by the
-Clownfish compiler to generate C header files and host language bindings.
-Methods, functions and variables are defined in normal C source files.
-
-The API for this alpha release of Clownfish has been cloaked.
-
-=head1 COPYRIGHT
-
-Clownfish is distributed under the Apache License, Version 2.0, as
-described in the file C<LICENSE> included with the distribution.
-
-=cut
-
